<div class="auth-redirect-page">
    <h2>Please log in or continue as a guest</h2>

    <div class="auth-section">
        <h3>Existing Customers</h3>
        <form action="<?php echo $block->getUrl('customer/account/loginPost') ?>" method="post">
            <input name="form_key" type="hidden" value="<?php echo $block->getFormKey(); ?>" />
            <label>Email:</label><input type="email" name="login[username]" required /><br/>
            <label>Password:</label><input type="password" name="login[password]" required /><br/>
            <button type="submit">Login</button>
        </form>
        <p><a href="<?php echo $block->getUrl('customer/account/forgotpassword') ?>">Forgot your password?</a></p>
    </div>

    <div class="guest-section">
        <h3>New or Guest Customer</h3>
        <form action="<?php echo $block->getUrl('checkout') ?>">
            <button type="submit">Continue as Guest</button>
        </form>
    </div>
</div>
