<?php

namespace PortalPeople\AuthRedirect\Model\ResourceModel\LoginAttemptLogger;

use Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection;

class Collection extends AbstractCollection
{
    protected function _construct()
    {
        $this->_init(
            \PortalPeople\AuthRedirect\Model\LoginAttemptLogger::class,
            \PortalPeople\AuthRedirect\Model\ResourceModel\LoginAttemptLogger::class
        );
    }
}