<div x-data="{ isLoading: false, ready: false }" x-init="ready = true">
    <template x-if="ready">
        <div x-show="!isLoading">
            <form id="login-form">
                <!-- Form content -->
                <input type="email" name="username" required placeholder="Email" />
                <input type="password" name="password" required placeholder="Password" />
                <button type="submit">Login</button>
            </form>
        </div>
    </template>
</div>
