<?php

namespace PortalPeople\AuthRedirect\Model\ResourceModel;

use Magento\Framework\Model\ResourceModel\Db\AbstractDb;

class LoginAttemptLogger extends AbstractDb
{
    protected function _construct()
    {
        $this->_init('portalpeople_login_attempt_logger', 'entity_id');
    }
}